if (exports) module.exports = null;
else if (define, define.amd) define([], factory.bind(root, root));
